@@ -4,9 +4,13 @@ import os
 from pathlib import Path
 from typing import Any
 
+# Hide development server warning
+# https://docs.djangoproject.com/en/stable/ref/django-admin/#envvar-DJANGO_RUNSERVER_HIDE_WARNING
+os.environ["DJANGO_RUNSERVER_HIDE_WARNING"] = "true"
+
 BASE_DIR = Path(__file__).parent
 
-DEBUG = os.environ.get("DEBUG", "") == "1"
+DEBUG = True
 
 SECRET_KEY = ")w%-67b9lurhzs*o2ow(e=n_^(n2!0_f*2+g+1*9tcn6_k58(f"
 
